<template>
    <div class="dialog-table-container">
        <el-table :element-loading-background="loadingColor" v-loading="loading" height="60vh" align="center"
            :data="tableData" class="dialog_table" :cell-style="{ 'text-align': 'center' }"
            :header-cell-style="{ 'text-align': 'center' }" @expand-change="expandChange" row-key="id">
            <el-table-column type="expand" label="点击查看详情" width="140">
                <template slot-scope="props">
                    <el-form label-position="top" class="dialog-table-expand">
                        <el-row>
                            <el-form-item label="解决问题：">
                                <span>{{ props.row.solveProblem }}</span>
                            </el-form-item>
                        </el-row>
                        <el-row>
                            <el-form-item label="运行实效：">
                                <span>{{ props.row.actualEffect }}</span>
                            </el-form-item>
                        </el-row>
                        <el-row>
                            <el-form-item label="佐证材料：">
                                <el-row v-if="props.row.fileList">
                                    <el-col :span="8" v-for="(file, index) in props.row
                                        .fileList" :key="index">
                                        <div class="file-style">
                                            <div class="file-item">
                                                <span class="file-name" :title="file.name
                                                        ? file.name
                                                        : file.fileName +
                                                        '.' +
                                                        file.extensionName
                                                    ">{{
        file.name
        ? file.name
        : file.fileName +
        '.' +
        file.extensionName
    }}</span>
                                                <span class="file-btn short">
                                                    <el-link type="primary" :underline="false" @click="
                                                        handlePreview(file)
                                                        " style="color: #fff">预览</el-link>
                                                    <el-link type="primary" :underline="false" style="color: #fff" @click="
                                                        handleDownloadFile(
                                                            file
                                                        )
                                                        ">下载</el-link>
                                                </span>
                                            </div>
                                        </div>
                                    </el-col>
                                </el-row>
                            </el-form-item>
                        </el-row>
                    </el-form>
                </template>
            </el-table-column>
            <el-table-column prop="resultName" label="应用名称" show-overflow-tooltip>
            </el-table-column>
            <el-table-column prop="pilotProjectName" label="试点项目名称" show-overflow-tooltip>
            </el-table-column>
            <el-table-column prop="unitName" label="开发区县" width="120" show-overflow-tooltip>
            </el-table-column>
            <el-table-column prop="resultDate" label="上线时间" width="100"></el-table-column>
        </el-table>
        <pagenation @currentChange="pageChange" class="pagenation" :pageResult="prarms.pageBean"></pagenation>
        <filePreview ref="filePreview" :appendToBody="true"></filePreview>
    </div>
</template>

<!--点击展开详情
上线应用
增加字段
1.解决问题 
2.运行实效 
3.应用截图
-->
<script>
import filePreview from '@/components/FilePreview/filePreview.vue'
import apiList from '@/api/bigScreen/districView.js'
import utils from '@/utils.js'
const portal = window.context.portal
import pagenation from './pagenation.vue'
export default {
    components: { pagenation, filePreview },
    props: {
        tableOptions: {
            type: Object,
            default: () => {
                return {}
            },
        },
    },
    data() {
        return {
            loadingColor: 'rgba(6, 46, 106, 0.4)',
            loading: false,
            previewUrl: `${portal}/file/onlinePreviewController/v1/getFileById_`,
            tableData: [],
            prarms: {
                pageBean: {
                    page: 1,
                    pageSize: 10,
                    total: 0,
                    showTotal: true,
                },
                params: {},
                querys: [
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'r.RESULT_FORM_',
                        relation: 'AND',
                        value: 3,
                    },
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'a.UNIT_CODE_',
                        relation: 'AND',
                        value: '',
                    },
                ],
            },
            prarmsFile: {
                pageBean: {
                    page: 1,
                    pageSize: -1,
                    showTotal: true,
                },
                querys: [
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'BIZ_ID_',
                        relation: 'AND',
                        value: '',
                    },
                ],
            },
        }
    },
    mounted() {
        this.prarms.querys[1].value = this.tableOptions.code
        this.loadData()
    },
    methods: {
        pageChange(key) {
            this.prarms.pageBean.page = key
            this.loadData()
        },
        expandChange(row, expandedRows) {
            console.log(row, expandedRows)
            if (row.fileList) return
            this.getFiles(row)
        },
        getFiles(row) {
            this.prarmsFile.querys[0].value = row.id
            apiList.getFiles(this.prarmsFile, (data) => {
                row.fileList = data.rows
            })
            let index = this.tableData.findIndex((item) => item.id == row.id)
            this.tableData.splice(index, 1, row)
        },
        handlePreview(file) {
            let id = file.fileId
                ? file.fileId
                : file.id
                    ? file.id
                    : file.response.fileId
            let type = file.fileType || (file.extensionName
                ? file.extensionName
                : file.name.split('.')[1])
            this.$refs.filePreview.previewUrl = this.previewUrl + id
            this.$refs.filePreview.open(type)
        },
        // 文件下载
        handleDownloadFile(file) {
            console.log(file)
            let id = file.fileId
                ? file.fileId
                : file.id
                    ? file.id
                    : file.response.fileId
            window.open(portal + `/file/v1/downloadFile?fileId=${id}`, '_self')
        },
        loadData() {
            this.loading = true
            let searchDate = sessionStorage.getItem('searchDate')
            searchDate = JSON.parse(searchDate)
            // this.prarms.querys[1].value = searchDate.year
            // this.prarms.querys[2].value = searchDate.quarter
            this.prarms.params = {
                year: searchDate.year,
                quarter: searchDate.quarter,
            }
            apiList.getPilotResultDetail(this.prarms, (res) => {
                console.log(res)
                if (res && res.rows) {
                    this.tableData = res.rows
                    this.prarms.pageBean.page = res.page
                    this.prarms.pageBean.pageSize = res.pageSize
                    this.prarms.pageBean.total = res.total
                }
                this.loading = false
            })
        },
    },
}
</script>
<style lang="scss" scoped>
.file-item {
    display: flex;
    justify-content: space-between;
    width: 100%;
    padding: 2px 10px;
    padding-right: 5px;
    border-radius: 2px;

    a {
        margin-right: 8px;
        user-select: none;
    }

    .file-name {
        width: calc(100% - 80px);
        overflow: hidden;
        text-overflow: ellipsis;
        white-space: nowrap;
    }

    .file-btn {
        display: inline-block;
        width: 140px;
    }

    .file-btn.short {
        width: 90px;
    }
}

.file-item:hover {
    background-color: rgba(1, 33, 90, 0.6);
}
</style>
<style lang="scss">
@import './table.scss';
</style>
